# Copyright 2012, 2013 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from charmworld.models import (
    CharmSource,
)
from charmworld.testing import (
    MongoTestBase,
)
from charmworld.migrations import migrate
from charmworld.migrations.migrate import Versions

from mock import patch


class MigrationTestBase(MongoTestBase):

    def setUp(self):
        super(MigrationTestBase, self).setUp()
        self.versions = Versions(migrate.get_migration_path())
        self.use_context(patch.object(migrate, 'configure_logging'))


class TestMigration025(MigrationTestBase):

    def setUp(self):
        super(TestMigration025, self).setUp()
        self.use_index_client()

    # Test creation of charm indices, but only if they do not exist already.
    def test_calls_setup_mongo_indices(self):
        source = CharmSource.from_request(self)
        index_name = 'owner_series_name_revision'
        exodus_update = self.versions.get_exodus(
            '025_charm_index_two.py')
        target = self.versions.get_pending_source(source, 25)
        index_info = target.collection.index_information()
        self.assertNotIn(index_name, index_info)
        exodus_update(source, target, 25)
        index_info = target.collection.index_information()
        self.assertIn(index_name, index_info)


class TestExodusRestrictions(MigrationTestBase):

    def test_exodus_restrictions(self):
        """Ensure that deploy-from-scratch does not violate exodus rules."""
        self.versions._check_exodus(self.versions.list_pending(0))
